@@ -275,10 +275,10 @@ class SmartSystem:
             wst.start()
 
     def on_message(self, message):
+        data = json.loads(message)
+        self.logger.debug(f'Received {data["type"]} message')
         self.logger.debug("------- Beginning of message ---------")
         self.logger.debug(message)
-        data = json.loads(message)
-        self.logger.info(f'Received {data["type"]} message')
         if data["type"] == "LOCATION":
             self.logger.debug(">>>>>>>>>>>>> Found LOCATION")
             self.parse_location(data)
